@@ -1,9 +1,19 @@
-u"""
+# -*- coding: utf-8 -*-
+
+from __future__ import unicode_literals
+
+"""
 Unit tests for spam filters.
 """
 
 from django.conf import settings
 from django.test import TestCase
+from django.utils import unittest
+
+try:
+    import honeypot
+except ImportError:
+    honeypot = None
 
 from envelope.spam_filters import check_honeypot
 
@@ -20,7 +30,7 @@ class FakeRequest(object):
 
 
 class CheckHoneypotTestCase(TestCase):
-    u"""
+    """
     Unit tests for ``check_honeypot`` spam filter.
     """
 
@@ -31,15 +41,16 @@ class CheckHoneypotTestCase(TestCase):
         self.honeypot = getattr(settings, 'HONEYPOT_FIELD_NAME', 'email2')
 
     def test_empty_honeypot(self):
-        u"""
+        """
         Empty honeypot field is a valid situation.
         """
-        self.request.POST[self.honeypot] = u''
+        self.request.POST[self.honeypot] = ''
         self.assertTrue(check_honeypot(self.request, self.form))
 
+    @unittest.skipIf(honeypot is None, "django-honeypot is not installed")
     def test_filled_honeypot(self):
-        u"""
+        """
         A value in the honeypot field is an indicator of a bot request.
         """
-        self.request.POST[self.honeypot] = u'Hi, this is a bot'
+        self.request.POST[self.honeypot] = 'Hi, this is a bot'
         self.assertFalse(check_honeypot(self.request, self.form))
