@@ -101,8 +101,8 @@ class ContactView(FormView):
                                              form=form)
         for (receiver, response) in responses:
             if not response:
-                return HttpResponseBadRequest(_("Rejected by %s") %
-                                                receiver.__name__)
+                error_message = _("Rejected by %s") % receiver.__name__
+                return HttpResponseBadRequest(error_message)
         form.save()
         messages.info(self.request,
                       _("Thank you for your message."),
@@ -129,10 +129,10 @@ def filter_spam(sender, request, form, **kwargs):
 
     TODO: more spam filters
     """
-    from envelope.spam_filters import check_honeypot
-    return check_honeypot(request, form)
+    if issubclass(sender, ContactView):
+        from envelope.spam_filters import check_honeypot
+        return check_honeypot(request, form)
 
 
 signals.before_send.connect(filter_spam,
-                            sender=ContactView,
                             dispatch_uid='envelope.views.filter_spam')
